summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commitc406d61deefc0c3e3173ebe77bfb38a1bc453ce7 (patch)
tree12ccf93b39a8eedba87ebbd7447d33e5ab59108a
parent373fe6f2b90bcd2e452f16115a4950a4b46c1f34 (diff)
downloadtdegames-c406d61d.tar.gz
tdegames-c406d61d.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegames@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
-rw-r--r--atlantik/COPYING.LIB2
-rw-r--r--kbackgammon/engines/fibs/kbgfibschat.cpp2
-rw-r--r--kbackgammon/engines/fibs/kbgfibschat.h2
-rw-r--r--kbackgammon/engines/fibs/kbginvite.cpp2
-rw-r--r--kbackgammon/kbgstatus.h2
-rw-r--r--kbattleship/kbattleship/dialogs/chatDlg.ui4
-rw-r--r--kbattleship/kbattleship/dialogs/connectDlg.ui6
-rw-r--r--kbattleship/kbattleship/dialogs/infoDlg.ui2
-rw-r--r--kbattleship/kbattleship/dialogs/serverDlg.ui6
-rw-r--r--kbattleship/kbattleship/dialogs/statDlg.ui2
-rw-r--r--kenolaba/EvalDlg.ui10
-rw-r--r--kjumpingcube/settings.ui2
-rw-r--r--kmahjongg/BoardLayout.cpp4
-rw-r--r--kmahjongg/BoardLayout.h2
-rw-r--r--kmahjongg/Preview.cpp12
-rw-r--r--kmahjongg/Preview.h2
-rw-r--r--kmahjongg/Tileset.cpp14
-rw-r--r--kmahjongg/Tileset.h6
-rw-r--r--kmahjongg/kmahjongg.cpp2
-rw-r--r--kmahjongg/settings.ui2
-rw-r--r--kmines/frame.cpp8
-rw-r--r--kolf/ball.cpp6
-rw-r--r--kolf/game.cpp2
-rw-r--r--kolf/game.h2
-rw-r--r--konquest/gamecore.cc26
-rw-r--r--konquest/gamecore.h10
-rw-r--r--konquest/newGameDlg_ui.ui2
-rw-r--r--kpat/freecell-solver/USAGE2
-rw-r--r--kpat/freecell-solver/caas.c2
-rw-r--r--kpat/freecell-solver/fcs.h2
-rw-r--r--kpat/freecell-solver/fcs_user.h2
-rw-r--r--kpat/freecell-solver/intrface.c2
-rw-r--r--kpat/freecell-solver/lib.c4
-rw-r--r--kpat/freecell-solver/main.c6
-rw-r--r--kpat/freecell-solver/preset.c2
-rw-r--r--kpat/freecell-solver/simpsim.c12
-rw-r--r--kpat/gamestats.ui2
-rw-r--r--kreversi/settings.ui2
-rw-r--r--kshisen/settings.ui2
-rw-r--r--ksnake/appearance.ui2
-rw-r--r--ksnake/general.ui2
-rw-r--r--kspaceduel/general.ui2
-rw-r--r--kspaceduel/mainview.cpp8
-rw-r--r--kspaceduel/mainview.h2
-rw-r--r--ktron/ai.ui2
-rw-r--r--ktron/appearance.ui2
-rw-r--r--ktron/general.ui2
-rw-r--r--ktron/tron.cpp4
-rw-r--r--ktuberling/pics/layout.xml6
-rw-r--r--ktuberling/playground.cpp40
-rw-r--r--ktuberling/playground.h6
-rw-r--r--ktuberling/soundfactory.cpp22
-rw-r--r--ktuberling/soundfactory.h4
-rw-r--r--ktuberling/todraw.cpp4
-rw-r--r--ktuberling/toplevel.cpp14
-rw-r--r--ktuberling/toplevel.h2
-rw-r--r--kwin4/kwin4/kspritecache.cpp8
-rw-r--r--kwin4/kwin4/kwin4doc.cpp2
-rw-r--r--kwin4/kwin4/settings.ui2
-rw-r--r--kwin4/kwin4/statistics.ui2
-rw-r--r--kwin4/kwin4/statuswidget.ui2
-rw-r--r--libkdegames/kchatbase.cpp8
-rw-r--r--libkdegames/kchatbase.h32
-rw-r--r--libkdegames/kgame/kgameio.h4
-rw-r--r--lskat/lskat/lskatview.cpp4
-rw-r--r--lskat/lskat/networkdlgbase.ui2
66 files changed, 186 insertions, 186 deletions
diff --git a/atlantik/COPYING.LIB b/atlantik/COPYING.LIB
index fbb61ee9..c4b38a7e 100644
--- a/atlantik/COPYING.LIB
+++ b/atlantik/COPYING.LIB
@@ -257,7 +257,7 @@ linked without the Library, or if the work is itself a library. The
threshold for this to be true is not precisely defined by law.
If such an object file uses only numerical parameters, data
-structure tqlayouts and accessors, and small macros and small inline
+structure layouts and accessors, and small macros and small inline
functions (ten lines or less in length), then the use of the object
file is unrestricted, regardless of whether it is legally a derivative
work. (Executables containing this object code plus portions of the
diff --git a/kbackgammon/engines/fibs/kbgfibschat.cpp b/kbackgammon/engines/fibs/kbgfibschat.cpp
index c1eca59d..7e4c9d7f 100644
--- a/kbackgammon/engines/fibs/kbgfibschat.cpp
+++ b/kbackgammon/engines/fibs/kbgfibschat.cpp
@@ -416,7 +416,7 @@ void KBgChat::setupDefault()
/*
* Overloaded member to create a TQListBoxItem for the chat window.
*/
-TQListBoxItem* KBgChat::tqlayoutMessage(const TQString& fromName, const TQString& text)
+TQListBoxItem* KBgChat::layoutMessage(const TQString& fromName, const TQString& text)
{
TQListBoxText* message = new KLBT(this, text, fromName);
return message;
diff --git a/kbackgammon/engines/fibs/kbgfibschat.h b/kbackgammon/engines/fibs/kbgfibschat.h
index 7dc0cfaf..a34a0c93 100644
--- a/kbackgammon/engines/fibs/kbgfibschat.h
+++ b/kbackgammon/engines/fibs/kbgfibschat.h
@@ -171,7 +171,7 @@ protected:
* Create a custom ListBoxItem that contains a formated string
* for the chat window.
*/
- virtual TQListBoxItem* tqlayoutMessage(const TQString& fromName, const TQString& text);
+ virtual TQListBoxItem* layoutMessage(const TQString& fromName, const TQString& text);
protected slots:
diff --git a/kbackgammon/engines/fibs/kbginvite.cpp b/kbackgammon/engines/fibs/kbginvite.cpp
index 666ba4c5..3870a6d2 100644
--- a/kbackgammon/engines/fibs/kbginvite.cpp
+++ b/kbackgammon/engines/fibs/kbginvite.cpp
@@ -75,7 +75,7 @@ KBgInvite::KBgInvite(const char *name)
hLine->setFrameStyle(TQFrame::Sunken|TQFrame::HLine);
/*
- * Set up tqlayouts
+ * Set up layouts
*/
TQBoxLayout *vbox = new TQVBoxLayout(this);
diff --git a/kbackgammon/kbgstatus.h b/kbackgammon/kbgstatus.h
index 05348157..255dc049 100644
--- a/kbackgammon/kbgstatus.h
+++ b/kbackgammon/kbgstatus.h
@@ -232,7 +232,7 @@ class KBgtqStatus : public TQObject
/*
* Set the n-th dice of player w to v. Nothing is done if w is
* invalid or if n is out of bounds. If v is invalid, the
- * value zero is assigned (i.e., the dice is tqinvalidated).
+ * value zero is assigned (i.e., the dice is invalidated).
*/
void setDice(const int &w, const int &n, const int &v);
diff --git a/kbattleship/kbattleship/dialogs/chatDlg.ui b/kbattleship/kbattleship/dialogs/chatDlg.ui
index ee49edb4..edf1fed1 100644
--- a/kbattleship/kbattleship/dialogs/chatDlg.ui
+++ b/kbattleship/kbattleship/dialogs/chatDlg.ui
@@ -27,7 +27,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayouter</cstring>
+ <cstring>layouter</cstring>
</property>
<grid>
<property name="name">
@@ -87,5 +87,5 @@
</widget>
</hbox>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kbattleship/kbattleship/dialogs/connectDlg.ui b/kbattleship/kbattleship/dialogs/connectDlg.ui
index 71241528..2bf0e8d5 100644
--- a/kbattleship/kbattleship/dialogs/connectDlg.ui
+++ b/kbattleship/kbattleship/dialogs/connectDlg.ui
@@ -15,9 +15,9 @@
<property name="caption">
<string>Connect to Server</string>
</property>
- <property name="tqlayoutMargin" stdset="0">
+ <property name="layoutMargin" stdset="0">
</property>
- <property name="tqlayoutSpacing" stdset="0">
+ <property name="layoutSpacing" stdset="0">
</property>
<grid>
<property name="name">
@@ -174,7 +174,7 @@
<includes>
<include location="global" impldecl="in implementation">kcombobox.h</include>
</includes>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kcombobox.h</includehint>
<includehint>klineedit.h</includehint>
diff --git a/kbattleship/kbattleship/dialogs/infoDlg.ui b/kbattleship/kbattleship/dialogs/infoDlg.ui
index a0e1ddfb..68c5671d 100644
--- a/kbattleship/kbattleship/dialogs/infoDlg.ui
+++ b/kbattleship/kbattleship/dialogs/infoDlg.ui
@@ -244,5 +244,5 @@
<slot>accept()</slot>
</connection>
</connections>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kbattleship/kbattleship/dialogs/serverDlg.ui b/kbattleship/kbattleship/dialogs/serverDlg.ui
index bf24ff75..e1888e8d 100644
--- a/kbattleship/kbattleship/dialogs/serverDlg.ui
+++ b/kbattleship/kbattleship/dialogs/serverDlg.ui
@@ -15,9 +15,9 @@
<property name="caption">
<string>Start Server</string>
</property>
- <property name="tqlayoutMargin" stdset="0">
+ <property name="layoutMargin" stdset="0">
</property>
- <property name="tqlayoutSpacing" stdset="0">
+ <property name="layoutSpacing" stdset="0">
</property>
<grid>
<property name="name">
@@ -128,5 +128,5 @@
</widget>
</grid>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kbattleship/kbattleship/dialogs/statDlg.ui b/kbattleship/kbattleship/dialogs/statDlg.ui
index 8587d3f1..feea1778 100644
--- a/kbattleship/kbattleship/dialogs/statDlg.ui
+++ b/kbattleship/kbattleship/dialogs/statDlg.ui
@@ -461,5 +461,5 @@
<data format="XPM.GZ" length="6001">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</data>
</image>
</images>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kenolaba/EvalDlg.ui b/kenolaba/EvalDlg.ui
index c92e7c67..c1fb6411 100644
--- a/kenolaba/EvalDlg.ui
+++ b/kenolaba/EvalDlg.ui
@@ -29,7 +29,7 @@
<property name="name">
<cstring>TabWidget2</cstring>
</property>
- <property name="tqlayoutSpacing" stdset="0">
+ <property name="layoutSpacing" stdset="0">
</property>
<widget class="TQWidget">
<property name="name">
@@ -66,7 +66,7 @@
<property name="name">
<cstring>Layout35</cstring>
</property>
- <property name="tqlayoutSpacing" stdset="0">
+ <property name="layoutSpacing" stdset="0">
</property>
<grid>
<property name="name">
@@ -303,7 +303,7 @@
<property name="name">
<cstring>Layout37</cstring>
</property>
- <property name="tqlayoutSpacing" stdset="0">
+ <property name="layoutSpacing" stdset="0">
</property>
<grid>
<property name="name">
@@ -577,7 +577,7 @@
<property name="name">
<cstring>Layout38</cstring>
</property>
- <property name="tqlayoutSpacing" stdset="0">
+ <property name="layoutSpacing" stdset="0">
</property>
<grid>
<property name="name">
@@ -1756,5 +1756,5 @@
<includes>
<include location="global" impldecl="in declaration">kseparator.h</include>
</includes>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kjumpingcube/settings.ui b/kjumpingcube/settings.ui
index f9539502..30b4010a 100644
--- a/kjumpingcube/settings.ui
+++ b/kjumpingcube/settings.ui
@@ -261,7 +261,7 @@
</widget>
</vbox>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kcolorbutton.h</includehint>
</includehints>
diff --git a/kmahjongg/BoardLayout.cpp b/kmahjongg/BoardLayout.cpp
index c9fd188e..8da404ae 100644
--- a/kmahjongg/BoardLayout.cpp
+++ b/kmahjongg/BoardLayout.cpp
@@ -29,7 +29,7 @@ bool BoardLayout::saveBoardLayout(const TQString where) {
return false;
}
- TQCString tmp = tqlayoutMagic1_0.utf8();
+ TQCString tmp = layoutMagic1_0.utf8();
if (f.writeBlock(tmp, tmp.length()) == -1) {
return(false);
}
@@ -71,7 +71,7 @@ bool BoardLayout::loadBoardLayout(const TQString from)
t.setCodec(TQTextCodec::codecForName("UTF-8"));
TQString s;
s = t.readLine();
- if (s != tqlayoutMagic1_0) {
+ if (s != layoutMagic1_0) {
f.close();
return(false);
}
diff --git a/kmahjongg/BoardLayout.h b/kmahjongg/BoardLayout.h
index 7bf58003..a9a809c7 100644
--- a/kmahjongg/BoardLayout.h
+++ b/kmahjongg/BoardLayout.h
@@ -4,7 +4,7 @@
#include <tqstring.h>
#include "KmTypes.h"
-const TQString tqlayoutMagic1_0 = "kmahjongg-tqlayout-v1.0";
+const TQString layoutMagic1_0 = "kmahjongg-tqlayout-v1.0";
class BoardLayout {
diff --git a/kmahjongg/Preview.cpp b/kmahjongg/Preview.cpp
index 5c5871bf..b99b3fd3 100644
--- a/kmahjongg/Preview.cpp
+++ b/kmahjongg/Preview.cpp
@@ -197,7 +197,7 @@ void Preview::drawPreview()
// specified bits in (tqlayout, background and tileset
if (!m_selectedFile.isEmpty())
{
- TQString backRaw, tqlayoutRaw, tilesetRaw, magic;
+ TQString backRaw, layoutRaw, tilesetRaw, magic;
TQFile in(m_selectedFile);
if (in.open(IO_ReadOnly))
@@ -212,7 +212,7 @@ void Preview::drawPreview()
}
tilesetRaw = stream.readLine();
backRaw = stream.readLine();
- tqlayoutRaw = stream.readLine();
+ layoutRaw = stream.readLine();
in.close();
tile = tilesetRaw;
@@ -233,11 +233,11 @@ void Preview::drawPreview()
back = locate("appdata", back);
}
- tqlayout = tqlayoutRaw;
+ tqlayout = layoutRaw;
tqlayout.tqreplace(":", "/kmahjongg/pics/");
if (!TQFile::exists(tqlayout))
{
- tqlayout = tqlayoutRaw;
+ tqlayout = layoutRaw;
tqlayout = "pics/" + tqlayout.right(tqlayout.length() - tqlayout.tqfind(":") - 1);
tqlayout = locate("appdata", tqlayout);
}
@@ -288,7 +288,7 @@ void Preview::applyChange()
}
// don't redraw for a tqlayout change
- if (m_previewType == board || m_previewType == theme) tqlayoutChange();
+ if (m_previewType == board || m_previewType == theme) layoutChange();
else boardRedraw(true);
// either way we mark the current value as unchanged
@@ -382,7 +382,7 @@ void Preview::saveTheme() {
KURL url = KFileDialog::getSaveURL(
NULL,
"*.theme",
- tqparentWidget(),
+ parentWidget(),
i18n("Save Theme" ));
if ( url.isEmpty() )
return;
diff --git a/kmahjongg/Preview.h b/kmahjongg/Preview.h
index 0c4b37c2..a987b7d2 100644
--- a/kmahjongg/Preview.h
+++ b/kmahjongg/Preview.h
@@ -71,7 +71,7 @@ signals:
void loadTileset(const TQString &);
void loadBackground(const TQString &, bool);
void loadBoard(const TQString &);
- void tqlayoutChange();
+ void layoutChange();
public slots:
void selectionChanged(int which);
diff --git a/kmahjongg/Tileset.cpp b/kmahjongg/Tileset.cpp
index fb4b1d05..b8c6ec2f 100644
--- a/kmahjongg/Tileset.cpp
+++ b/kmahjongg/Tileset.cpp
@@ -16,9 +16,9 @@ static unsigned char mini_bits[] = {
0xff, 0xff, 0x0f, 0xff, 0xff, 0x0f, 0xff, 0xff, 0x07, 0xff, 0xff, 0x03,
};
-#define tqmask_width 40
-#define tqmask_height 56
-static unsigned char tqmask_bits[] = {
+#define mask_width 40
+#define mask_height 56
+static unsigned char mask_bits[] = {
0xf0, 0xff, 0xff, 0xff, 0xff, 0xf8, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff,
0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
@@ -48,8 +48,8 @@ static unsigned char tqmask_bits[] = {
// ---------------------------------------------------------
Tileset::Tileset(bool scale):
- tqmaskBits(tqmask_width, tqmask_height, tqmask_bits, true),
- tqmaskBitsMini(mini_width, mini_height, mini_bits, true)
+ maskBits(mask_width, mask_height, mask_bits, true),
+ maskBitsMini(mini_width, mini_height, mini_bits, true)
{
isScaled = scale;
divisor = (isScaled) ? 2 : 1;
@@ -198,10 +198,10 @@ void Tileset::createPixmap(TQRgb *src, TQPixmap &dest, bool scale, bool shadow)
// create the pixmap and initialise the drawing tqmask
if (!scale) {
dest.convertFromImage(buff);
- dest.setMask(tqmaskBits);
+ dest.setMask(maskBits);
} else {
dest.convertFromImage(buff.smoothScale(w/2, h/2));
- dest.setMask(tqmaskBitsMini);
+ dest.setMask(maskBitsMini);
}
}
diff --git a/kmahjongg/Tileset.h b/kmahjongg/Tileset.h
index f728dfb0..c93cf102 100644
--- a/kmahjongg/Tileset.h
+++ b/kmahjongg/Tileset.h
@@ -61,14 +61,14 @@ class Tileset {
private:
- TQBitmap tqmaskBits; // xbm tqmask for the tile
- TQBitmap tqmaskBitsMini; // xbm tqmask for the tile
+ TQBitmap maskBits; // xbm tqmask for the tile
+ TQBitmap maskBitsMini; // xbm tqmask for the tile
TQRgb* tiles; // Buffer containing all tiles (unselected glyphs)
TQRgb* selectedTiles; // Buffer containing all tiles (selected glyphs)
// in version 0.5 we have moved ftom using images and calculating
- // tqmasks etc, to using pixmaps and letting the blt do the hard work,
+ // masks etc, to using pixmaps and letting the blt do the hard work,
// in hardware.
TQPixmap selectedPix[maxTiles]; // selected tiles
TQPixmap unselectedPix[maxTiles]; // unselected tiles
diff --git a/kmahjongg/kmahjongg.cpp b/kmahjongg/kmahjongg.cpp
index d9f20522..49246f92 100644
--- a/kmahjongg/kmahjongg.cpp
+++ b/kmahjongg/kmahjongg.cpp
@@ -100,7 +100,7 @@ KMahjongg::KMahjongg( TQWidget* tqparent, const char *name)
connect( previewLoad, TQT_SIGNAL( boardRedraw(bool) ),
bw, TQT_SLOT( drawBoard(bool) ) );
- connect( previewLoad, TQT_SIGNAL( tqlayoutChange() ),
+ connect( previewLoad, TQT_SIGNAL( layoutChange() ),
this, TQT_SLOT( newGame() ) );
diff --git a/kmahjongg/settings.ui b/kmahjongg/settings.ui
index 2cb105d8..594cf9b7 100644
--- a/kmahjongg/settings.ui
+++ b/kmahjongg/settings.ui
@@ -167,5 +167,5 @@
</widget>
</vbox>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kmines/frame.cpp b/kmines/frame.cpp
index 7c712383..b5c154b0 100644
--- a/kmines/frame.cpp
+++ b/kmines/frame.cpp
@@ -41,14 +41,14 @@ void FieldFrame::adjustSize()
TQBitmap tqmask;
for (uint i=0; i<Nb_Pixmap_Types; i++) {
- TQPixmap tqmask_pm = tqmask;
- drawPixmap(tqmask_pm, (PixmapType)i, true);
+ TQPixmap mask_pm = tqmask;
+ drawPixmap(mask_pm, (PixmapType)i, true);
drawPixmap(_pixmaps[i], (PixmapType)i, false);
_pixmaps[i].setMask(tqmask);
}
for (uint i=0; i<Nb_Advised; i++) {
- TQPixmap tqmask_pm = tqmask;
- drawAdvised(tqmask_pm, i, true);
+ TQPixmap mask_pm = tqmask;
+ drawAdvised(mask_pm, i, true);
drawAdvised(_advised[i], i, false);
_advised[i].setMask(tqmask);
}
diff --git a/kolf/ball.cpp b/kolf/ball.cpp
index 569a5ba2..0e25422b 100644
--- a/kolf/ball.cpp
+++ b/kolf/ball.cpp
@@ -308,10 +308,10 @@ void Ball::collisionDetect(double oldx, double oldy)
for (iterpoint = points.first(); iterpoint; iterpoint = points.next())
{
//kdDebug(12007) << "-----\n";
- const Wall *tqparentWall = iterpoint->tqparentWall();
- const TQPoint qp(iterpoint->x() + tqparentWall->x(), iterpoint->y() + tqparentWall->y());
+ const Wall *parentWall = iterpoint->parentWall();
+ const TQPoint qp(iterpoint->x() + parentWall->x(), iterpoint->y() + parentWall->y());
const Point p(qp.x(), qp.y());
- const TQPoint qother = TQPoint(tqparentWall->startPoint() == qp? tqparentWall->endPoint() : tqparentWall->startPoint()) + TQPoint(tqparentWall->x(), tqparentWall->y());
+ const TQPoint qother = TQPoint(parentWall->startPoint() == qp? parentWall->endPoint() : parentWall->startPoint()) + TQPoint(parentWall->x(), parentWall->y());
const Point other(qother.x(), qother.y());
// vector of wall
diff --git a/kolf/game.cpp b/kolf/game.cpp
index 1a7bfe4d..a6f02a79 100644
--- a/kolf/game.cpp
+++ b/kolf/game.cpp
@@ -3462,7 +3462,7 @@ void KolfGame::showInfo()
void KolfGame::showInfoDlg(bool addDontShowAgain)
{
- KMessageBox::information(tqparentWidget(),
+ KMessageBox::information(parentWidget(),
i18n("Course name: %1").tqarg(holeInfo.name()) + TQString("\n")
+ i18n("Created by %1").tqarg(holeInfo.author()) + TQString("\n")
+ i18n("%1 holes").tqarg(highestHole),
diff --git a/kolf/game.h b/kolf/game.h
index 3bcaaaf5..ec986c52 100644
--- a/kolf/game.h
+++ b/kolf/game.h
@@ -483,7 +483,7 @@ public:
void dontMove() { dontmove = true; };
void updateVisible();
- Wall *tqparentWall() { return wall; }
+ Wall *parentWall() { return wall; }
protected:
Wall *wall;
diff --git a/konquest/gamecore.cc b/konquest/gamecore.cc
index df8ba86e..e02c115f 100644
--- a/konquest/gamecore.cc
+++ b/konquest/gamecore.cc
@@ -242,16 +242,16 @@ const int Map::getColumns() const
//---------------------------------------------------------------------------
Sector::Sector()
-: TQObject(0,0), planet( NULL ), tqparentMap(NULL ), x(0), y(0)
+: TQObject(0,0), planet( NULL ), parentMap(NULL ), x(0), y(0)
{}
Sector::Sector( Map *newParentMap, int xPos, int yPos )
-: TQObject(0,0), planet(NULL), tqparentMap( newParentMap ), x(xPos), y(yPos)
+: TQObject(0,0), planet(NULL), parentMap( newParentMap ), x(xPos), y(yPos)
{
}
Sector::Sector( const Sector & other )
-: TQObject(0,0), planet(other.planet), tqparentMap(other.tqparentMap), x(other.x), y(other.y)
+: TQObject(0,0), planet(other.planet), parentMap(other.parentMap), x(other.x), y(other.y)
{
}
@@ -294,7 +294,7 @@ Sector::operator=( const Sector &other )
x = other.x;
y = other.y;
planet = other.planet;
- tqparentMap = other.tqparentMap;
+ parentMap = other.parentMap;
return *this;
}
@@ -302,7 +302,7 @@ Sector::operator=( const Sector &other )
void
Sector::select()
{
- tqparentMap->setSelectedSector( x, y );
+ parentMap->setSelectedSector( x, y );
emit selected();
}
@@ -322,29 +322,29 @@ int Sector::getColumn()
Planet::Planet( TQString planetName, Sector &newParentSector, Player *initialOwner,
int newProd, double newKillP, double newMorale )
- : TQObject(0,0), name(planetName), owner(initialOwner), tqparentSector(newParentSector),
+ : TQObject(0,0), name(planetName), owner(initialOwner), parentSector(newParentSector),
homeFleet( this, newProd ), killPercentage(newKillP), morale( newMorale ), productionRate(newProd)
{
- tqparentSector.setPlanet( this );
+ parentSector.setPlanet( this );
}
Planet::~Planet() {}
Planet *
-Planet::createPlayerPlanet( Sector &tqparentSector, Player *initialOwner, TQString planetName )
+Planet::createPlayerPlanet( Sector &parentSector, Player *initialOwner, TQString planetName )
{
CoreLogic clogic;
double morale = clogic.generateMorale();
- return new Planet( planetName, tqparentSector, initialOwner,
+ return new Planet( planetName, parentSector, initialOwner,
10, 0.400, morale );
}
Planet *
-Planet::createNeutralPlanet( Sector &tqparentSector, Player *initialOwner, TQString planetName )
+Planet::createNeutralPlanet( Sector &parentSector, Player *initialOwner, TQString planetName )
{
CoreLogic clogic;
double morale = clogic.generateMorale();
@@ -353,7 +353,7 @@ Planet::createNeutralPlanet( Sector &tqparentSector, Player *initialOwner, TQStr
int productionRate = (int)clogic.generatePlanetProduction();
- return new Planet( planetName, tqparentSector,
+ return new Planet( planetName, parentSector,
initialOwner, productionRate, killP, morale );
}
@@ -398,7 +398,7 @@ Planet::setProduction( int newProduction )
void
Planet::select()
{
- tqparentSector.select();
+ parentSector.select();
emit selected();
}
@@ -423,7 +423,7 @@ Planet::getName() const
Sector &
Planet::getSector() const
{
- return tqparentSector;
+ return parentSector;
}
void
diff --git a/konquest/gamecore.h b/konquest/gamecore.h
index 80dab502..edbd4210 100644
--- a/konquest/gamecore.h
+++ b/konquest/gamecore.h
@@ -185,9 +185,9 @@ private:
public:
virtual ~Planet();
- static Planet *createPlayerPlanet( Sector &tqparentSector,
+ static Planet *createPlayerPlanet( Sector &parentSector,
Player *initialOwner, TQString planetName );
- static Planet *createNeutralPlanet( Sector &tqparentSector,
+ static Planet *createNeutralPlanet( Sector &parentSector,
Player *initialOwner, TQString planetName );
Sector &getSector() const;
@@ -214,7 +214,7 @@ signals:
private:
TQString name;
Player *owner;
- Sector &tqparentSector;
+ Sector &parentSector;
DefenseFleet homeFleet;
double killPercentage;
@@ -235,7 +235,7 @@ public:
// constructors
Sector();
- Sector( Map *tqparentMap, int xpos, int ypos );
+ Sector( Map *parentMap, int xpos, int ypos );
Sector( const Sector & );
// assignment operator (makes initialization easy)
@@ -261,7 +261,7 @@ protected slots:
protected:
Planet *planet; // a sector has 0 or 1 planets
- Map *tqparentMap;
+ Map *parentMap;
int x, y;
};
diff --git a/konquest/newGameDlg_ui.ui b/konquest/newGameDlg_ui.ui
index 0fc2942f..fd7f782d 100644
--- a/konquest/newGameDlg_ui.ui
+++ b/konquest/newGameDlg_ui.ui
@@ -433,7 +433,7 @@
<data format="PNG" length="1002">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</data>
</image>
</images>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>minimap.h</includehint>
</includehints>
diff --git a/kpat/freecell-solver/USAGE b/kpat/freecell-solver/USAGE
index 583624ca..9cffe4e1 100644
--- a/kpat/freecell-solver/USAGE
+++ b/kpat/freecell-solver/USAGE
@@ -259,7 +259,7 @@ Also note that Freecell tests are not suitable for solving Simple Simon games
and Simple Simon tests are not suitable for solving anything except Simple
Simon.
-Tests can be grouped together into random groups using tqparenthesis
+Tests can be grouped together into random groups using parenthesis
(e.g: "(0123)") or square brackets ("[012][3456789]"). Such grouping is
only relevant to the Random DFS scan (see below).
diff --git a/kpat/freecell-solver/caas.c b/kpat/freecell-solver/caas.c
index 3654ab59..4d359a40 100644
--- a/kpat/freecell-solver/caas.c
+++ b/kpat/freecell-solver/caas.c
@@ -372,7 +372,7 @@ static GCC_INLINE void freecell_solver_cache_stacks(
);
#if 0
) /* In order to settle gvim and other editors that
- are keen on tqparenthesis matching */
+ are keen on parenthesis matching */
#endif
replace_with_cached(cached_stack != NULL);
diff --git a/kpat/freecell-solver/fcs.h b/kpat/freecell-solver/fcs.h
index 6bca557f..b865a3f0 100644
--- a/kpat/freecell-solver/fcs.h
+++ b/kpat/freecell-solver/fcs.h
@@ -190,7 +190,7 @@ typedef struct freecell_solver_instance
int depth,
void * instance,
fcs_state_with_locations_t * state,
- int tqparent_iter_num
+ int parent_iter_num
);
void * debug_iter_output_context;
diff --git a/kpat/freecell-solver/fcs_user.h b/kpat/freecell-solver/fcs_user.h
index 0d9fe815..8ddbf6f2 100644
--- a/kpat/freecell-solver/fcs_user.h
+++ b/kpat/freecell-solver/fcs_user.h
@@ -165,7 +165,7 @@ typedef void (*freecell_solver_user_iter_handler_t)
int iter_num,
int depth,
void * ptr_state,
- int tqparent_iter_num,
+ int parent_iter_num,
void * context
);
diff --git a/kpat/freecell-solver/intrface.c b/kpat/freecell-solver/intrface.c
index e70e8fca..44aa29a0 100644
--- a/kpat/freecell-solver/intrface.c
+++ b/kpat/freecell-solver/intrface.c
@@ -795,7 +795,7 @@ static void trace_solution(
s1 = instance->final_state;
- /* Retrace the step from the current state to its tqparents */
+ /* Retrace the step from the current state to its parents */
while (s1->tqparent != NULL)
{
/* Mark the state as part of the non-optimized solution */
diff --git a/kpat/freecell-solver/lib.c b/kpat/freecell-solver/lib.c
index e887fe00..1839614b 100644
--- a/kpat/freecell-solver/lib.c
+++ b/kpat/freecell-solver/lib.c
@@ -892,7 +892,7 @@ static void freecell_solver_user_iter_handler_wrapper(
int depth,
void * lp_instance,
fcs_state_with_locations_t * ptr_state_with_locations,
- int tqparent_iter_num
+ int parent_iter_num
)
{
fcs_user_t * user;
@@ -904,7 +904,7 @@ static void freecell_solver_user_iter_handler_wrapper(
iter_num,
depth,
(void *)ptr_state_with_locations,
- tqparent_iter_num,
+ parent_iter_num,
user->iter_handler_context
);
diff --git a/kpat/freecell-solver/main.c b/kpat/freecell-solver/main.c
index f4949741..181039b6 100644
--- a/kpat/freecell-solver/main.c
+++ b/kpat/freecell-solver/main.c
@@ -43,7 +43,7 @@ static void my_iter_handler(
int iter_num,
int depth,
void * ptr_state,
- int tqparent_iter_num,
+ int parent_iter_num,
void * lp_context
)
{
@@ -57,7 +57,7 @@ static void my_iter_handler(
);
if (context->display_parent_iter_num)
{
- fprintf(stdout, "Parent Iteration: %i\n", tqparent_iter_num);
+ fprintf(stdout, "Parent Iteration: %i\n", parent_iter_num);
}
fprintf(stdout, "\n");
@@ -255,7 +255,7 @@ help_screen_t help_screens[] = {
" cards above it.\n"
" 'h' - move a sequence to a tqparent on the same stack.\n"
"\n"
-" Tests are grouped with tqparenthesis or square brackets. Each group\n"
+" Tests are grouped with parenthesis or square brackets. Each group\n"
" will be randomized as a whole by the random-dfs scan.\n"
"\n"
"\n"
diff --git a/kpat/freecell-solver/preset.c b/kpat/freecell-solver/preset.c
index 9286fd83..16a02f1d 100644
--- a/kpat/freecell-solver/preset.c
+++ b/kpat/freecell-solver/preset.c
@@ -457,7 +457,7 @@ int freecell_solver_apply_tests_order(
}
if (! is_group)
{
- *error_string = strdup("There's a renegade right tqparenthesis or bracket.");
+ *error_string = strdup("There's a renegade right parenthesis or bracket.");
return 3;
}
is_group = 0;
diff --git a/kpat/freecell-solver/simpsim.c b/kpat/freecell-solver/simpsim.c
index a51b0c50..5ef8a411 100644
--- a/kpat/freecell-solver/simpsim.c
+++ b/kpat/freecell-solver/simpsim.c
@@ -22,8 +22,8 @@
#define fcs_is_ss_false_parent(tqparent, child) \
(fcs_card_card_num(tqparent) == fcs_card_card_num(child)+1)
-#define fcs_suit_is_ss_true_parent(tqparent_suit, child_suit) \
- ((tqparent_suit) == (child_suit))
+#define fcs_suit_is_ss_true_parent(parent_suit, child_suit) \
+ ((parent_suit) == (child_suit))
#define fcs_is_ss_true_parent(tqparent, child) \
( \
@@ -1450,7 +1450,7 @@ int freecell_solver_sfs_simple_simon_move_sequence_to_parent_on_the_same_stack(
int check;
int stack, cards_num, pc, cc;
- fcs_card_t tqparent_card, child_card;
+ fcs_card_t parent_card, child_card;
int a;
int after_junk_num_freestacks;
int false_seq_index;
@@ -1471,10 +1471,10 @@ int freecell_solver_sfs_simple_simon_move_sequence_to_parent_on_the_same_stack(
/* Search for a tqparent card */
for(pc=0; pc < cards_num-1 ; pc++)
{
- tqparent_card = fcs_stack_card(state, stack, pc);
+ parent_card = fcs_stack_card(state, stack, pc);
if (
fcs_is_ss_true_parent(
- tqparent_card,
+ parent_card,
fcs_stack_card(state, stack, pc+1)
)
)
@@ -1487,7 +1487,7 @@ int freecell_solver_sfs_simple_simon_move_sequence_to_parent_on_the_same_stack(
{
child_card = fcs_stack_card(state, stack, cc);
if (fcs_is_ss_true_parent(
- tqparent_card,
+ parent_card,
child_card
)
)
diff --git a/kpat/gamestats.ui b/kpat/gamestats.ui
index c0dff2c3..ac2597fd 100644
--- a/kpat/gamestats.ui
+++ b/kpat/gamestats.ui
@@ -268,5 +268,5 @@
<Q_SLOTS>
<slot>setGameType(int)</slot>
</Q_SLOTS>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kreversi/settings.ui b/kreversi/settings.ui
index f19dec90..4d66c5df 100644
--- a/kreversi/settings.ui
+++ b/kreversi/settings.ui
@@ -319,7 +319,7 @@
<slot>setEnabled(bool)</slot>
</connection>
</connections>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kurlrequester.h</includehint>
<includehint>klineedit.h</includehint>
diff --git a/kshisen/settings.ui b/kshisen/settings.ui
index 197d547a..773b75a5 100644
--- a/kshisen/settings.ui
+++ b/kshisen/settings.ui
@@ -251,5 +251,5 @@
</spacer>
</vbox>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/ksnake/appearance.ui b/ksnake/appearance.ui
index 5aa105f7..7696fc19 100644
--- a/ksnake/appearance.ui
+++ b/ksnake/appearance.ui
@@ -80,7 +80,7 @@
</spacer>
</vbox>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kcolorbutton.h</includehint>
</includehints>
diff --git a/ksnake/general.ui b/ksnake/general.ui
index 0b0fe912..39e3f45b 100644
--- a/ksnake/general.ui
+++ b/ksnake/general.ui
@@ -198,5 +198,5 @@
</spacer>
</vbox>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kspaceduel/general.ui b/kspaceduel/general.ui
index 71b74f1f..05d5ba83 100644
--- a/kspaceduel/general.ui
+++ b/kspaceduel/general.ui
@@ -333,5 +333,5 @@
<slot>setEnabled(bool)</slot>
</connection>
</connections>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kspaceduel/mainview.cpp b/kspaceduel/mainview.cpp
index ea17594d..8204ffd0 100644
--- a/kspaceduel/mainview.cpp
+++ b/kspaceduel/mainview.cpp
@@ -1002,12 +1002,12 @@ void MyMainView::closeSettings(){
}
TQCanvasPixmapArray* MyMainView::loadOldPixmapSequence(const TQString& datapattern,
- const TQString& tqmaskpattern, int framecount)
+ const TQString& maskpattern, int framecount)
{
int image;
TQPtrList<TQPixmap> pixmaplist;
TQPtrList<TQPoint> pointlist;
- TQString dataname, tqmaskname;
+ TQString dataname, maskname;
TQPixmap *pix;
TQBitmap *bitmap;
int hotx=0, hoty=0;
@@ -1017,7 +1017,7 @@ TQCanvasPixmapArray* MyMainView::loadOldPixmapSequence(const TQString& datapatte
{
// #### Why is this a TQString??
dataname.sprintf( datapattern.ascii(), image );
- tqmaskname.sprintf( tqmaskpattern.ascii(), image );
+ maskname.sprintf( maskpattern.ascii(), image );
TQFile file(dataname);
if( file.open( IO_ReadOnly ) )
@@ -1039,7 +1039,7 @@ TQCanvasPixmapArray* MyMainView::loadOldPixmapSequence(const TQString& datapatte
}
pix = new TQPixmap( dataname );
- bitmap = new TQBitmap( tqmaskname );
+ bitmap = new TQBitmap( maskname );
pix->setMask( *bitmap );
pixmaplist.append( pix );
diff --git a/kspaceduel/mainview.h b/kspaceduel/mainview.h
index ab4a4fcc..ec182408 100644
--- a/kspaceduel/mainview.h
+++ b/kspaceduel/mainview.h
@@ -52,7 +52,7 @@ protected:
virtual void keyReleaseEvent(TQKeyEvent *event);
SConfig modifyConfig(SConfig conf);
TQCanvasPixmapArray* loadOldPixmapSequence(const TQString& datapattern,
- const TQString& tqmaskpattern, int framecount=1);
+ const TQString& maskpattern, int framecount=1);
void moveShips();
void moveBullets();
void moveMines();
diff --git a/ktron/ai.ui b/ktron/ai.ui
index c036876d..dc84bc32 100644
--- a/ktron/ai.ui
+++ b/ktron/ai.ui
@@ -137,5 +137,5 @@
</widget>
</vbox>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/ktron/appearance.ui b/ktron/appearance.ui
index 7c2f67dd..d6176a69 100644
--- a/ktron/appearance.ui
+++ b/ktron/appearance.ui
@@ -292,7 +292,7 @@
<tabstop>kcfg_Color_Player1</tabstop>
<tabstop>kcfg_Color_Player2</tabstop>
</tabstops>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kurlrequester.h</includehint>
<includehint>klineedit.h</includehint>
diff --git a/ktron/general.ui b/ktron/general.ui
index b312dd6f..0971ec1a 100644
--- a/ktron/general.ui
+++ b/ktron/general.ui
@@ -215,5 +215,5 @@
</widget>
</vbox>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/ktron/tron.cpp b/ktron/tron.cpp
index 92a5d296..c168070d 100644
--- a/ktron/tron.cpp
+++ b/ktron/tron.cpp
@@ -313,8 +313,8 @@ void Tron::updatePixmap()
}
// draw frame
- TQColor light=tqparentWidget()->tqcolorGroup().midlight();
- TQColor dark=tqparentWidget()->tqcolorGroup().mid();
+ TQColor light=parentWidget()->tqcolorGroup().midlight();
+ TQColor dark=parentWidget()->tqcolorGroup().mid();
p.setPen(NoPen);
p.setBrush(light);
diff --git a/ktuberling/pics/layout.xml b/ktuberling/pics/layout.xml
index 84b09a2a..9e87dae7 100644
--- a/ktuberling/pics/layout.xml
+++ b/ktuberling/pics/layout.xml
@@ -11,7 +11,7 @@
<ktuberling>
- <playground gameboard="potato-game.png" tqmasks="potato-tqmask.png">
+ <playground gameboard="potato-game.png" masks="potato-tqmask.png">
<menuitem action="playground_potato_guy">
<label>Potato &amp;Guy</label>
@@ -269,7 +269,7 @@
</playground>
- <playground gameboard="penguin-game.png" tqmasks="penguin-tqmask.png">
+ <playground gameboard="penguin-game.png" masks="penguin-tqmask.png">
<menuitem action="playground_penguin">
<label>&amp;Penguin</label>
@@ -422,7 +422,7 @@
</playground>
- <playground gameboard="aquarium-game.png" tqmasks="aquarium-tqmask.png">
+ <playground gameboard="aquarium-game.png" masks="aquarium-tqmask.png">
<menuitem action="playground_aquarium">
<label>&amp;Aquarium</label>
diff --git a/ktuberling/playground.h b/ktuberling/playground.h
index a428f88b..65fbaff0 100644
--- a/ktuberling/playground.h
+++ b/ktuberling/playground.h
@@ -51,8 +51,8 @@ protected:
private:
- bool registerPlayGrounds(TQDomDocument &tqlayoutDocument);
- bool loadPlayGround(TQDomDocument &tqlayoutDocument, uint toLoad);
+ bool registerPlayGrounds(TQDomDocument &layoutDocument);
+ bool loadPlayGround(TQDomDocument &layoutDocument, uint toLoad);
void loadFailure();
void setupGeometry();
bool zone(TQPoint &position);
@@ -62,7 +62,7 @@ private:
private:
TQPixmap gameboard; // Picture of the game board
- TQBitmap tqmasks; // Pictures of the objects' tqshapes
+ TQBitmap masks; // Pictures of the objects' tqshapes
TQRect editableArea; // Part of the gameboard where the player can lay down objects
TQString menuItem, // Menu item describing describing this gameboard
editableSound; // Sound associated with this area
diff --git a/ktuberling/soundfactory.cpp b/ktuberling/soundfactory.cpp
index 5bb309d8..f10d0a8c 100644
--- a/ktuberling/soundfactory.cpp
+++ b/ktuberling/soundfactory.cpp
@@ -25,10 +25,10 @@ SoundFactory::SoundFactory(TopLevel *tqparent, const char *name, uint selectedLa
namesList = filesList = 0;
- TQDomDocument tqlayoutsDocument;
- bool ok = topLevel->loadLayout(tqlayoutsDocument);
- if (ok) ok = registerLanguages(tqlayoutsDocument);
- if (ok) ok = loadLanguage(tqlayoutsDocument, selectedLanguage);
+ TQDomDocument layoutsDocument;
+ bool ok = topLevel->loadLayout(layoutsDocument);
+ if (ok) ok = registerLanguages(layoutsDocument);
+ if (ok) ok = loadLanguage(layoutsDocument, selectedLanguage);
if (!ok) loadFailure();
}
@@ -42,9 +42,9 @@ SoundFactory::~SoundFactory()
// Change the language
void SoundFactory::change(uint selectedLanguage)
{
- TQDomDocument tqlayoutsDocument;
- bool ok = topLevel->loadLayout(tqlayoutsDocument);
- if (ok) ok = loadLanguage(tqlayoutsDocument, selectedLanguage);
+ TQDomDocument layoutsDocument;
+ bool ok = topLevel->loadLayout(layoutsDocument);
+ if (ok) ok = loadLanguage(layoutsDocument, selectedLanguage);
if (!ok) loadFailure();
}
@@ -74,14 +74,14 @@ void SoundFactory::loadFailure()
}
// Register the various languages
-bool SoundFactory::registerLanguages(TQDomDocument &tqlayoutDocument)
+bool SoundFactory::registerLanguages(TQDomDocument &layoutDocument)
{
TQDomNodeList languagesList, menuItemsList, labelsList;
TQDomElement languageElement, menuItemElement, labelElement;
TQDomAttr codeAttribute, actionAttribute;
bool enabled;
- languagesList = tqlayoutDocument.elementsByTagName("language");
+ languagesList = layoutDocument.elementsByTagName("language");
if (languagesList.count() < 1)
return false;
@@ -110,7 +110,7 @@ bool SoundFactory::registerLanguages(TQDomDocument &tqlayoutDocument)
}
// Load the sounds of one given language
-bool SoundFactory::loadLanguage(TQDomDocument &tqlayoutDocument, uint toLoad)
+bool SoundFactory::loadLanguage(TQDomDocument &layoutDocument, uint toLoad)
{
TQDomNodeList languagesList,
soundNamesList;
@@ -118,7 +118,7 @@ bool SoundFactory::loadLanguage(TQDomDocument &tqlayoutDocument, uint toLoad)
soundNameElement;
TQDomAttr nameAttribute, fileAttribute;
- languagesList = tqlayoutDocument.elementsByTagName("language");
+ languagesList = layoutDocument.elementsByTagName("language");
if (toLoad >= languagesList.count())
return false;
diff --git a/ktuberling/soundfactory.h b/ktuberling/soundfactory.h
index 6fe923bc..76272e0a 100644
--- a/ktuberling/soundfactory.h
+++ b/ktuberling/soundfactory.h
@@ -28,8 +28,8 @@ public:
protected:
- bool registerLanguages(TQDomDocument &tqlayoutDocument);
- bool loadLanguage(TQDomDocument &tqlayoutDocument, uint toLoad);
+ bool registerLanguages(TQDomDocument &layoutDocument);
+ bool loadLanguage(TQDomDocument &layoutDocument, uint toLoad);
private:
diff --git a/ktuberling/todraw.cpp b/ktuberling/todraw.cpp
index c148b3a0..cec7b014 100644
--- a/ktuberling/todraw.cpp
+++ b/ktuberling/todraw.cpp
@@ -44,7 +44,7 @@ ToDraw &ToDraw::operator=(const ToDraw &model)
// Draw an object previously laid down on the game board
void ToDraw::draw(TQPainter &artist, const TQRect &area,
const TQRect *objectsLayout,
- const TQPixmap *gameboard, const TQBitmap *tqmasks) const
+ const TQPixmap *gameboard, const TQBitmap *masks) const
{
if (!position.intersects(area)) return;
@@ -52,7 +52,7 @@ void ToDraw::draw(TQPainter &artist, const TQRect &area,
TQBitmap tqshapeBitmap(objectsLayout[number].size());
bitBlt(&objectPixmap, TQPoint(0, 0), gameboard, objectsLayout[number], TQt::CopyROP);
- bitBlt(&tqshapeBitmap, TQPoint(0, 0), tqmasks, objectsLayout[number], TQt::CopyROP);
+ bitBlt(&tqshapeBitmap, TQPoint(0, 0), masks, objectsLayout[number], TQt::CopyROP);
objectPixmap.setMask(tqshapeBitmap);
artist.drawPixmap(position.topLeft(), objectPixmap);
}
diff --git a/ktuberling/toplevel.cpp b/ktuberling/toplevel.cpp
index c0131d26..0563d856 100644
--- a/ktuberling/toplevel.cpp
+++ b/ktuberling/toplevel.cpp
@@ -186,19 +186,19 @@ void TopLevel::changeLanguage(uint newLanguage)
soundFactory->change(newLanguage);
}
-// Load the tqlayouts file
-bool TopLevel::loadLayout(TQDomDocument &tqlayoutDocument)
+// Load the layouts file
+bool TopLevel::loadLayout(TQDomDocument &layoutDocument)
{
- TQFile tqlayoutFile(TQFile::encodeName(locate("data", "ktuberling/pics/tqlayout.xml")));
- if (!tqlayoutFile.open(IO_ReadOnly))
+ TQFile layoutFile(TQFile::encodeName(locate("data", "ktuberling/pics/tqlayout.xml")));
+ if (!layoutFile.open(IO_ReadOnly))
return false;
- if (!tqlayoutDocument.setContent(&tqlayoutFile))
+ if (!layoutDocument.setContent(&layoutFile))
{
- tqlayoutFile.close();
+ layoutFile.close();
return false;
}
- tqlayoutFile.close();
+ layoutFile.close();
return true;
}
diff --git a/ktuberling/toplevel.h b/ktuberling/toplevel.h
index 04ceaa96..a92d27c4 100644
--- a/ktuberling/toplevel.h
+++ b/ktuberling/toplevel.h
@@ -32,7 +32,7 @@ public:
void registerLanguage(const TQString &menuItem, const char *actionId, bool enabled);
void changeGameboard(uint newGameboard);
void changeLanguage(uint newLanguage);
- bool loadLayout(TQDomDocument &tqlayoutDocument);
+ bool loadLayout(TQDomDocument &layoutDocument);
void playSound(const TQString &ref) const;
inline bool isSoundEnabled() const {return soundEnabled;}
diff --git a/kwin4/kwin4/kspritecache.cpp b/kwin4/kwin4/kspritecache.cpp
index 342369c9..c49332f7 100644
--- a/kwin4/kwin4/kspritecache.cpp
+++ b/kwin4/kwin4/kspritecache.cpp
@@ -221,7 +221,7 @@ TQCanvasPixmapArray *KSpriteCache::createPixmapArray(KConfig *config,TQString na
//kdDebug(11002) << " Reading " << number << " frames " << endl;
TQString pixfile=config->readPathEntry(name+"file");
- TQString tqmaskfile=config->readPathEntry(name+"tqmask");
+ TQString maskfile=config->readPathEntry(name+"tqmask");
// Load a given set of images or replace a %d by a sequence if there are
// less image names than number given
@@ -232,7 +232,7 @@ TQCanvasPixmapArray *KSpriteCache::createPixmapArray(KConfig *config,TQString na
{
TQString tmpfile,tmptqmask;
tmpfile.sprintf(pixfile.latin1(),i);
- tmptqmask.sprintf(tqmaskfile.latin1(),i);
+ tmptqmask.sprintf(maskfile.latin1(),i);
pixmap=loadPixmap(tmpfile,tmptqmask);
if (!pixmap) kdError() << "Could not create pixmap="<<tmpfile << " with tqmask " << tmptqmask << endl;
@@ -255,9 +255,9 @@ TQCanvasPixmapArray *KSpriteCache::createPixmapArray(KConfig *config,TQString na
double step;
if (number>1) step=(100.0-finalscale)/100.0/(double)(number-1);
else step=1.0;
- //kdDebug(11002) << " Scaling " << number << " pics axis="<<axis<<" final="<<finalscale<<" file="<<pixfile<< " tqmask="<<tqmaskfile<<endl;
+ //kdDebug(11002) << " Scaling " << number << " pics axis="<<axis<<" final="<<finalscale<<" file="<<pixfile<< " tqmask="<<maskfile<<endl;
- pixmap=loadPixmap(pixfile,tqmaskfile);
+ pixmap=loadPixmap(pixfile,maskfile);
for (unsigned int j=0;j<(unsigned int)number;j++)
{
TQWMatrix matrix;
diff --git a/kwin4/kwin4/kwin4doc.cpp b/kwin4/kwin4/kwin4doc.cpp
index 73ea8520..a4c2c622 100644
--- a/kwin4/kwin4/kwin4doc.cpp
+++ b/kwin4/kwin4/kwin4doc.cpp
@@ -932,7 +932,7 @@ void Kwin4Doc::createIO(KPlayer *player,KGameIO::IOMode io)
if (global_debug>1) kdDebug(12010) << "Creating KEYBOARD IO " << endl;
// We want the player to work over keyboard
KGameKeyIO *input;
- input=new KGameKeyIO(pView->tqparentWidget());
+ input=new KGameKeyIO(pView->parentWidget());
// Connect keys input to a function to process the actual input
connect((KGameKeyIO *)input,TQT_SIGNAL(signalKeyEvent(KGameIO *,TQDataStream &,TQKeyEvent *,bool *)),
pView,TQT_SLOT(slotKeyInput(KGameIO *,TQDataStream &,TQKeyEvent *,bool *)));
diff --git a/kwin4/kwin4/settings.ui b/kwin4/kwin4/settings.ui
index 1cb6f11d..c64677c6 100644
--- a/kwin4/kwin4/settings.ui
+++ b/kwin4/kwin4/settings.ui
@@ -244,5 +244,5 @@
</spacer>
</grid>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kwin4/kwin4/statistics.ui b/kwin4/kwin4/statistics.ui
index 457d7dae..b02e8be6 100644
--- a/kwin4/kwin4/statistics.ui
+++ b/kwin4/kwin4/statistics.ui
@@ -245,5 +245,5 @@
<tabstop>pushButton2</tabstop>
<tabstop>pushButton1</tabstop>
</tabstops>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kwin4/kwin4/statuswidget.ui b/kwin4/kwin4/statuswidget.ui
index ee131828..41d6bef5 100644
--- a/kwin4/kwin4/statuswidget.ui
+++ b/kwin4/kwin4/statuswidget.ui
@@ -259,5 +259,5 @@
</widget>
</grid>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/libkdegames/kchatbase.cpp b/libkdegames/kchatbase.cpp
index 182f96a9..00827e6d 100644
--- a/libkdegames/kchatbase.cpp
+++ b/libkdegames/kchatbase.cpp
@@ -349,15 +349,15 @@ void KChatBase::addItem(const TQListBoxItem* text)
void KChatBase::addMessage(const TQString& fromName, const TQString& text)
{
//maybe "%1 says: %2" or so
- addItem(tqlayoutMessage(fromName, text));
+ addItem(layoutMessage(fromName, text));
}
void KChatBase::addSystemMessage(const TQString& fromName, const TQString& text)
{
- addItem(tqlayoutSystemMessage(fromName, text));
+ addItem(layoutSystemMessage(fromName, text));
}
-TQListBoxItem* KChatBase::tqlayoutMessage(const TQString& fromName, const TQString& text)
+TQListBoxItem* KChatBase::layoutMessage(const TQString& fromName, const TQString& text)
{
//TODO: KChatBaseConfigure? - e.g. color
TQListBoxItem* message;
@@ -379,7 +379,7 @@ TQListBoxItem* KChatBase::tqlayoutMessage(const TQString& fromName, const TQStri
return message;
}
-TQListBoxItem* KChatBase::tqlayoutSystemMessage(const TQString& fromName, const TQString& text)
+TQListBoxItem* KChatBase::layoutSystemMessage(const TQString& fromName, const TQString& text)
{
//TODO: KChatBaseConfigure? - e.g. color
diff --git a/libkdegames/kgame/kgameio.h b/libkdegames/kgame/kgameio.h
index 2f4b89ab..6f6a6ae9 100644
--- a/libkdegames/kgame/kgameio.h
+++ b/libkdegames/kgame/kgameio.h
@@ -187,7 +187,7 @@ public:
* handler signalKeyEvent and can be used to generate
* a valid move for the player.
* Note the widget you pass to the constructor must be
- * the main window of your application, e.g. view->tqparentWidget()
+ * the main window of your application, e.g. view->parentWidget()
* as QT does not forward your keyevents otherwise. This means
* that this might be a different widget comapred to the one you
* use for mouse inputs!
@@ -199,7 +199,7 @@ public:
* this,TQT_SLOT(slotKeyInput(KGameIO *,TQDataStream &,TQKeyEvent *,bool *)));
* \endcode
*
- * @param tqparent The tqparents widget whose keyboard events * should be grabbed
+ * @param tqparent The parents widget whose keyboard events * should be grabbed
*/
KGameKeyIO(TQWidget *tqparent);
virtual ~KGameKeyIO();
diff --git a/lskat/lskat/lskatview.cpp b/lskat/lskat/lskatview.cpp
index 8603a662..1ead3427 100644
--- a/lskat/lskat/lskatview.cpp
+++ b/lskat/lskat/lskatview.cpp
@@ -136,7 +136,7 @@ LSkatView::LSkatView(TQWidget *tqparent, const char *name) : TQWidget(tqparent,
// Access the document with the game data
LSkatDoc *LSkatView::getDocument() const
{
- LSkatApp *theApp=(LSkatApp *) tqparentWidget();
+ LSkatApp *theApp=(LSkatApp *) parentWidget();
return theApp->getDocument();
}
@@ -900,7 +900,7 @@ void LSkatView::moveTimerReady()
TQString ld,s;
if (cardmovecnt>=MOVECOUNTER)
{
- LSkatApp *m=(LSkatApp *) tqparentWidget();
+ LSkatApp *m=(LSkatApp *) parentWidget();
moveTimer->stop();
cardmovecnt=0;
update(TQRect(cardend,getDocument()->cardsize));
diff --git a/lskat/lskat/networkdlgbase.ui b/lskat/lskat/networkdlgbase.ui
index 09371e87..5451289b 100644
--- a/lskat/lskat/networkdlgbase.ui
+++ b/lskat/lskat/networkdlgbase.ui
@@ -302,5 +302,5 @@
<slot access="protected">toggleServerClient()</slot>
<slot access="protected">gameSelected(int nr)</slot>
</Q_SLOTS>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/ktuberling/playground.cpp b/ktuberling/playground.cpp
index cdd03d89..c2da26bf 100644
--- a/ktuberling/playground.cpp
+++ b/ktuberling/playground.cpp
@@ -38,10 +38,10 @@ PlayGround::PlayGround(TopLevel *tqparent, const char *name, uint selectedGamebo
setBackgroundColor(white);
- TQDomDocument tqlayoutsDocument;
- bool ok = topLevel->loadLayout(tqlayoutsDocument);
- if (ok) ok = registerPlayGrounds(tqlayoutsDocument);
- if (ok) ok = loadPlayGround(tqlayoutsDocument, selectedGameboard);
+ TQDomDocument layoutsDocument;
+ bool ok = topLevel->loadLayout(layoutsDocument);
+ if (ok) ok = registerPlayGrounds(layoutsDocument);
+ if (ok) ok = loadPlayGround(layoutsDocument, selectedGameboard);
if (!ok) loadFailure();
currentAction = 0;
@@ -71,9 +71,9 @@ void PlayGround::reset()
// Change the gameboard
void PlayGround::change(uint selectedGameboard)
{
- TQDomDocument tqlayoutsDocument;
- bool ok = topLevel->loadLayout(tqlayoutsDocument);
- if (ok) ok = loadPlayGround(tqlayoutsDocument, selectedGameboard);
+ TQDomDocument layoutsDocument;
+ bool ok = topLevel->loadLayout(layoutsDocument);
+ if (ok) ok = loadPlayGround(layoutsDocument, selectedGameboard);
if (!ok) loadFailure();
toDraw.clear();
@@ -221,7 +221,7 @@ void PlayGround::drawGameboard( TQPainter &artist, const TQRect &area ) const
for (TQPtrListIterator<ToDraw> currentObject(toDraw);
currentObject.current();
++currentObject)
- currentObject.current()->draw(artist, area, objectsLayout, &gameboard, &tqmasks);
+ currentObject.current()->draw(artist, area, objectsLayout, &gameboard, &masks);
}
// Painting event
@@ -257,7 +257,7 @@ void PlayGround::mousePressEvent( TQMouseEvent *event )
TQPixmap object(objectsLayout[draggedNumber].size());
TQBitmap tqshape(objectsLayout[draggedNumber].size());
bitBlt(&object, TQPoint(0, 0), &gameboard, objectsLayout[draggedNumber], TQt::CopyROP);
- bitBlt(&tqshape, TQPoint(0, 0), &tqmasks, objectsLayout[draggedNumber], TQt::CopyROP);
+ bitBlt(&tqshape, TQPoint(0, 0), &masks, objectsLayout[draggedNumber], TQt::CopyROP);
object.setMask(tqshape);
draggedCursor = new TQCursor(object, position.x(), position.y());
@@ -325,13 +325,13 @@ void PlayGround::mouseReleaseEvent( TQMouseEvent *event )
}
// Register the various playgrounds
-bool PlayGround::registerPlayGrounds(TQDomDocument &tqlayoutDocument)
+bool PlayGround::registerPlayGrounds(TQDomDocument &layoutDocument)
{
TQDomNodeList playGroundsList, menuItemsList, labelsList;
TQDomElement playGroundElement, menuItemElement, labelElement;
TQDomAttr actionAttribute;
- playGroundsList = tqlayoutDocument.elementsByTagName("playground");
+ playGroundsList = layoutDocument.elementsByTagName("playground");
if (playGroundsList.count() < 1)
return false;
@@ -357,20 +357,20 @@ bool PlayGround::registerPlayGrounds(TQDomDocument &tqlayoutDocument)
return true;
}
-// Load background and draggable objects tqmasks
-bool PlayGround::loadPlayGround(TQDomDocument &tqlayoutDocument, uint toLoad)
+// Load background and draggable objects masks
+bool PlayGround::loadPlayGround(TQDomDocument &layoutDocument, uint toLoad)
{
TQDomNodeList playGroundsList,
editableAreasList, categoriesList, objectsList,
- gameAreasList, tqmaskAreasList, soundNamesList, labelsList;
+ gameAreasList, maskAreasList, soundNamesList, labelsList;
TQDomElement playGroundElement,
editableAreaElement, categoryElement, objectElement,
- gameAreaElement, tqmaskAreaElement, soundNameElement, labelElement;
- TQDomAttr gameboardAttribute, tqmasksAttribute,
+ gameAreaElement, maskAreaElement, soundNameElement, labelElement;
+ TQDomAttr gameboardAttribute, masksAttribute,
leftAttribute, topAttribute, rightAttribute, bottomAttribute,
refAttribute;
- playGroundsList = tqlayoutDocument.elementsByTagName("playground");
+ playGroundsList = layoutDocument.elementsByTagName("playground");
if (toLoad >= playGroundsList.count())
return false;
@@ -380,8 +380,8 @@ bool PlayGround::loadPlayGround(TQDomDocument &tqlayoutDocument, uint toLoad)
if (!gameboard.load(locate("data", "ktuberling/pics/" + gameboardAttribute.value())))
return false;
- tqmasksAttribute = playGroundElement.attributeNode("tqmasks");
- if (!tqmasks.load(locate("data", "ktuberling/pics/" + tqmasksAttribute.value())))
+ masksAttribute = playGroundElement.attributeNode("masks");
+ if (!masks.load(locate("data", "ktuberling/pics/" + masksAttribute.value())))
return false;
editableAreasList = playGroundElement.elementsByTagName("editablearea");
@@ -550,7 +550,7 @@ bool PlayGround::zone(TQPoint &position)
TQBitmap tqshape(objectsLayout[draggedNumber].size());
TQPoint relative(position.x() - toUpdate.x(),
position.y() - toUpdate.y());
- bitBlt(&tqshape, TQPoint(0, 0), &tqmasks, objectsLayout[draggedNumber], TQt::CopyROP);
+ bitBlt(&tqshape, TQPoint(0, 0), &masks, objectsLayout[draggedNumber], TQt::CopyROP);
if (!tqshape.convertToImage().pixelIndex(relative.x(), relative.y())) continue;
toDraw.remove(draggedZOrder);
diff --git a/libkdegames/kchatbase.h b/libkdegames/kchatbase.h
index 5e97b80c..77a6ed4f 100644
--- a/libkdegames/kchatbase.h
+++ b/libkdegames/kchatbase.h
@@ -171,8 +171,8 @@ class KChatBasePrivate;
*
* To add a message just call addMessage with the nickname of the player
* who sent the message and the message itself. If you don't want to use
* tqlayoutMessage by any reason you can also call addItem directly. But you
* should better replace tqlayoutMessage instead.
*
* You probably don't want to use the abstract class KChatBase directly but use
* one of the derived classess KChat or KGameChat. The latter is the
@@ -314,35 +314,35 @@ public:
/**
* Same as setNameFont but applies only to system messages.
- * @see tqlayoutSystemMessage
+ * @see layoutSystemMessage
**/
void setSystemNameFont(const TQFont& font);
/**
* Same as setMessageFont but applies only to system messages.
- * @see tqlayoutSystemMessage
+ * @see layoutSystemMessage
**/
void setSystemMessageFont(const TQFont& font);
/**
* Same as setBothFont but applies only to system messages.
- * @see tqlayoutSystemMessage
+ * @see layoutSystemMessage
**/
void setSystemBothFont(const TQFont& font);
/**
* This font should be used for the name (the "from: " part) of a
* message. tqlayoutMessage uses this to set the font using
* KChatBaseText::setNameFont but if you want to overwrite
* tqlayoutMessage you should do this yourself.
* @return The font that is used for the name part of the message.
**/
const TQFont& nameFont() const;
/**
* This font should be used for a message. tqlayoutMessage sets the
* font of a message using KChatBaseText::setMessageFont but if ypu
* replace tqlayoutMessage with your own function you should use
* messageFont() yourself.
* @return The font that is used for a message
**/
@@ -350,13 +350,13 @@ public:
/**
* Same as systemNameFont but applies only to system messages.
- * @see tqlayoutSystemMessage
+ * @see layoutSystemMessage
**/
const TQFont& systemNameFont() const;
/**
* Same as systemMessageFont but applies only to system messages.
- * @see tqlayoutSystemMessage
+ * @see layoutSystemMessage
**/
const TQFont& systemMessageFont() const;
@@ -406,7 +406,7 @@ public slots:
* Maybe you want to replace this with a function that creates a nicer text
* than "fromName: text"
*
* Update: the function tqlayoutMessage is called by this now. This
* means that you will get user defined outlook on the messages :-)
* @param fromName The player who sent this message
* @param text The text to be added
@@ -415,7 +415,7 @@ public slots:
/**
* This works just like addMessage but adds a system message.
* tqlayoutSystemMessage is used to generate the displayed item. System
* messages will have a different look than player messages.
*
* You may wish to use this to display status information from your game.
@@ -483,16 +483,16 @@ protected:
* created which shows the message in this format: "fromName: text".
* This should fit most peoples needs but needs further improvements.
**/
- virtual TQListBoxItem* tqlayoutMessage(const TQString& fromName, const TQString& text);
+ virtual TQListBoxItem* layoutMessage(const TQString& fromName, const TQString& text);
/**
* Create a TQListBoxItem for this message. This does the same as
* tqlayoutMessage but generates a system message. You might want to
* use such a message to display e.g. status information from your game.
*
* The default implementation just prepends "--- ".
**/
- virtual TQListBoxItem* tqlayoutSystemMessage(const TQString& fromName, const TQString& text);
+ virtual TQListBoxItem* layoutSystemMessage(const TQString& fromName, const TQString& text);
private slots:
/**
@@ -171,8 +171,8 @@ class KChatBasePrivate;
* To add a message just call addMessage with the nickname of the player
* who sent the message and the message itself. If you don't want to use
- * tqlayoutMessage by any reason you can also call addItem directly. But you
- * should better replace tqlayoutMessage instead.
+ * layoutMessage by any reason you can also call addItem directly. But you
+ * should better replace layoutMessage instead.
*
* You probably don't want to use the abstract class KChatBase directly but use
@@ -314,35 +314,35 @@ public:
/**
* This font should be used for the name (the "from: " part) of a
- * message. tqlayoutMessage uses this to set the font using
+ * message. layoutMessage uses this to set the font using
* KChatBaseText::setNameFont but if you want to overwrite
@@ -314,35 +314,35 @@ public:
* KChatBaseText::setNameFont but if you want to overwrite
- * tqlayoutMessage you should do this yourself.
+ * layoutMessage you should do this yourself.
* @return The font that is used for the name part of the message.
**/
@@ -314,35 +314,35 @@ public:
const TQFont& nameFont() const;
/**
- * This font should be used for a message. tqlayoutMessage sets the
+ * This font should be used for a message. layoutMessage sets the
* font of a message using KChatBaseText::setMessageFont but if ypu
@@ -314,35 +314,35 @@ public:
* font of a message using KChatBaseText::setMessageFont but if ypu
- * replace tqlayoutMessage with your own function you should use
+ * replace layoutMessage with your own function you should use
* messageFont() yourself.
* @return The font that is used for a message
@@ -406,7 +406,7 @@ public slots:
* than "fromName: text"
*
- * Update: the function tqlayoutMessage is called by this now. This
+ * Update: the function layoutMessage is called by this now. This
* means that you will get user defined outlook on the messages :-)
* @param fromName The player who sent this message
@@ -415,7 +415,7 @@ public slots:
/**
* This works just like addMessage but adds a system message.
- * tqlayoutSystemMessage is used to generate the displayed item. System
+ * layoutSystemMessage is used to generate the displayed item. System
* messages will have a different look than player messages.
*
@@ -483,16 +483,16 @@ protected:
/**
* Create a TQListBoxItem for this message. This does the same as
- * tqlayoutMessage but generates a system message. You might want to
+ * layoutMessage but generates a system message. You might want to
* use such a message to display e.g. status information from your game.
*